@@ -57,7 +57,7 @@
     <message>
         <location filename="../AccountsDialog.qml" line="35"/>
         <source>Database error. Unable to delete account</source>
-        <translation type="unfinished"></translation>
+        <translation>Errore database. Impossibile cancellare l&apos;account</translation>
     </message>
     <message>
         <location filename="../AccountsDialog.qml" line="79"/>
@@ -159,22 +159,22 @@
     <message>
         <location filename="../ConfirmDeleteDialog.qml" line="30"/>
         <source>Confirm Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Conferma Eliminazione</translation>
     </message>
     <message>
         <location filename="../ConfirmDeleteDialog.qml" line="42"/>
         <source>Please choose from where you wish to delete the selected videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Seleziona da dove vuoi cancellare i video selezionati</translation>
     </message>
     <message>
         <location filename="../ConfirmDeleteDialog.qml" line="55"/>
         <source>Archive</source>
-        <translation type="unfinished">Archivio</translation>
+        <translation>Archivio</translation>
     </message>
     <message>
         <location filename="../ConfirmDeleteDialog.qml" line="65"/>
         <source>Device</source>
-        <translation type="unfinished"></translation>
+        <translation>Dispositivo</translation>
     </message>
 </context>
 <context>
@@ -312,24 +312,24 @@
         <location filename="../InboxDelegate.qml" line="44"/>
         <location filename="../InboxDelegate.qml" line="46"/>
         <source>From </source>
-        <translation type="unfinished"></translation>
+        <translation>Da </translation>
     </message>
     <message>
         <location filename="../InboxDelegate.qml" line="45"/>
         <location filename="../InboxDelegate.qml" line="47"/>
         <location filename="../InboxDelegate.qml" line="95"/>
         <source> on </source>
-        <translation type="unfinished"> il </translation>
+        <translation> il </translation>
     </message>
     <message>
         <location filename="../InboxDelegate.qml" line="95"/>
         <source>By </source>
-        <translation type="unfinished">Da </translation>
+        <translation>Da </translation>
     </message>
     <message>
         <location filename="../InboxDelegate.qml" line="145"/>
         <source>Views</source>
-        <translation type="unfinished"></translation>
+        <translation>Visualizzazioni</translation>
     </message>
 </context>
 <context>
@@ -337,12 +337,12 @@
     <message>
         <location filename="../InboxDialog.qml" line="57"/>
         <source>Inbox</source>
-        <translation type="unfinished"></translation>
+        <translation>Posta in Arrivo</translation>
     </message>
     <message>
         <location filename="../InboxDialog.qml" line="69"/>
         <source>No messages found</source>
-        <translation type="unfinished"></translation>
+        <translation>Nessun messaggio trovato</translation>
     </message>
 </context>
 <context>
@@ -493,47 +493,47 @@
     <message>
         <location filename="../PlaylistDialog.qml" line="114"/>
         <source>Playlist Info</source>
-        <translation type="unfinished"></translation>
+        <translation>Info Playlist</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="159"/>
         <source>Title</source>
-        <translation type="unfinished">Titolo</translation>
+        <translation>Titolo</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="165"/>
         <source>Videos</source>
-        <translation type="unfinished">Video</translation>
+        <translation>Video</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="185"/>
         <source>Created</source>
-        <translation type="unfinished"></translation>
+        <translation>Creata</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="191"/>
         <source>Updated</source>
-        <translation type="unfinished"></translation>
+        <translation>Ultimo aggiornamento</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="219"/>
         <source>Description</source>
-        <translation type="unfinished">Descrizione</translation>
+        <translation>Descrizione</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="237"/>
         <source>No description</source>
-        <translation type="unfinished">Nessuna descrizione</translation>
+        <translation>Nessuna descrizione</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="252"/>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation>Riproduci</translation>
     </message>
     <message>
         <location filename="../PlaylistDialog.qml" line="276"/>
         <source>Download</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -571,22 +571,22 @@
     <message>
         <location filename="../PlaylistVideosView.qml" line="169"/>
         <source>Videos</source>
-        <translation type="unfinished">Video</translation>
+        <translation>Video</translation>
     </message>
     <message>
         <location filename="../PlaylistVideosView.qml" line="183"/>
         <source>Updated</source>
-        <translation type="unfinished"></translation>
+        <translation>Ultimo aggiornamento</translation>
     </message>
     <message>
         <location filename="../PlaylistVideosView.qml" line="206"/>
         <source>Play all</source>
-        <translation type="unfinished"></translation>
+        <translation>Riproduci tutti</translation>
     </message>
     <message>
         <location filename="../PlaylistVideosView.qml" line="214"/>
         <source>Loading playlist videos. Please wait</source>
-        <translation type="unfinished"></translation>
+        <translation>Caricamento dei video della playlist. Attendere</translation>
     </message>
 </context>
 <context>
@@ -599,7 +599,7 @@
     <message>
         <location filename="../PlaylistsView.qml" line="54"/>
         <source>Playlist deleted</source>
-        <translation type="unfinished"></translation>
+        <translation>Playlist cancellata</translation>
     </message>
     <message>
         <source>New playlist</source>
@@ -780,7 +780,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="45"/>
         <source>Midnight</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="46"/>
@@ -941,12 +941,12 @@
     <message>
         <location filename="../SettingsDialog.qml" line="229"/>
         <source>Your facebook token has been deleted</source>
-        <translation type="unfinished"></translation>
+        <translation>Il tuo permesso facebook è stato cancellato</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="232"/>
         <source>Database error. Unable to delete facebook token</source>
-        <translation type="unfinished"></translation>
+        <translation>Errore database. Impossibile cancellare il permesso facebook</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="279"/>
@@ -1001,12 +1001,12 @@
     <message>
         <location filename="../SettingsDialog.qml" line="422"/>
         <source>Social networks</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="433"/>
         <source>Delete facebook token</source>
-        <translation type="unfinished"></translation>
+        <translation>Cancella permesso facebook</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="499"/>
@@ -1304,12 +1304,12 @@
     <message>
         <location filename="../UserInfoDialog.qml" line="106"/>
         <source>Profile</source>
-        <translation type="unfinished"></translation>
+        <translation>Profilo</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="152"/>
         <source>Uploads</source>
-        <translation type="unfinished">Caricati</translation>
+        <translation>Caricati</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="158"/>
@@ -1319,59 +1319,59 @@
     <message>
         <location filename="../UserInfoDialog.qml" line="178"/>
         <source>Name</source>
-        <translation type="unfinished"></translation>
+        <translation>Nome</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="184"/>
         <source>Age</source>
-        <translation type="unfinished"></translation>
+        <translation>Età</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="197"/>
         <location filename="../UserInfoDialog.qml" line="215"/>
         <location filename="../UserInfoDialog.qml" line="221"/>
         <source>None</source>
-        <translation type="unfinished">Nessuna</translation>
+        <translation>Nessuna</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="203"/>
         <source>Gender</source>
-        <translation type="unfinished"></translation>
+        <translation>Genere</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="209"/>
         <source>Location</source>
-        <translation type="unfinished"></translation>
+        <translation>Luogo</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="215"/>
         <source>Male</source>
-        <translation type="unfinished"></translation>
+        <translation>Uomo</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="215"/>
         <source>Female</source>
-        <translation type="unfinished"></translation>
+        <translation>Donna</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="236"/>
         <source>About</source>
-        <translation type="unfinished"></translation>
+        <translation>Informazioni personali</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="254"/>
         <source>No info</source>
-        <translation type="unfinished"></translation>
+        <translation>Nessuna informazione</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="269"/>
         <source>Unsubscribe</source>
-        <translation type="unfinished">Cancellati</translation>
+        <translation>Cancellati</translation>
     </message>
     <message>
         <location filename="../UserInfoDialog.qml" line="269"/>
         <source>Subscribe</source>
-        <translation type="unfinished">Iscriviti</translation>
+        <translation>Iscriviti</translation>
     </message>
     <message>
         <source>Videos</source>
@@ -1598,7 +1598,7 @@
     <message>
         <location filename="../VideoPlaybackView.qml" line="165"/>
         <source>Loading...</source>
-        <translation type="unfinished">Caricamento...</translation>
+        <translation>Caricamento...</translation>
     </message>
 </context>
 <context>
@@ -1765,37 +1765,37 @@
     <message>
         <location filename="../main.qml" line="453"/>
         <source>Your rating has been added</source>
-        <translation type="unfinished">Il tuo voto è stato aggiunto</translation>
+        <translation>Il tuo voto è stato aggiunto</translation>
     </message>
     <message>
         <location filename="../main.qml" line="455"/>
         <source>Your comment has been added</source>
-        <translation type="unfinished">Il tuo commento è stato aggiunto</translation>
+        <translation>Il tuo commento è stato aggiunto</translation>
     </message>
     <message>
         <location filename="../main.qml" line="460"/>
         <source>Video shared on facebook</source>
-        <translation type="unfinished">Video condiviso su Facebook</translation>
+        <translation>Video condiviso su Facebook</translation>
     </message>
     <message>
         <location filename="../main.qml" line="461"/>
         <source>Videos(s) added to download queue</source>
-        <translation type="unfinished"></translation>
+        <translation>Video aggiunto(i) alla coda download</translation>
     </message>
     <message>
         <location filename="../main.qml" line="465"/>
         <source>You are not signed in to a YouTube account</source>
-        <translation type="unfinished">Non hai effettuato l&apos;accesso con un account YouTube</translation>
+        <translation>Non hai effettuato l&apos;accesso con un account YouTube</translation>
     </message>
     <message>
         <location filename="../main.qml" line="466"/>
         <source>No YouTube account found</source>
-        <translation type="unfinished"></translation>
+        <translation>Nessun account YouTube trovato</translation>
     </message>
     <message>
         <location filename="../main.qml" line="467"/>
         <source>Use the cuteTube Player to access this feature</source>
-        <translation type="unfinished"></translation>
+        <translation>Utilizza il player di cuteTube per accedere a questa funzione</translation>
     </message>
     <message>
         <location filename="../main.qml" line="34"/>
@@ -1895,7 +1895,7 @@
     <message>
         <location filename="../main.qml" line="454"/>
         <source>You cannot rate your own videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Non puoi votare i tuoi video</translation>
     </message>
     <message>
         <location filename="../main.qml" line="456"/>
@@ -1905,7 +1905,7 @@
     <message>
         <location filename="../main.qml" line="457"/>
         <source>Video already in favourites</source>
-        <translation type="unfinished"></translation>
+        <translation>Il video è già nei preferiti</translation>
     </message>
     <message>
         <location filename="../main.qml" line="458"/>
@@ -1915,7 +1915,7 @@
     <message>
         <location filename="../main.qml" line="468"/>
         <source>Unable to play videos at 360p quality or higher</source>
-        <translation type="unfinished"></translation>
+        <translation>Impossibile riprodurre il video in qualità 360p o superiore</translation>
     </message>
     <message>
         <location filename="../main.qml" line="270"/>
